function res = compute_all_statistics(inputfolder)

if nargin < 1, inputfolder='base_cal'; 
else, inputfolder=sprintf('%g',inputfolder); end

fprintf('Computing statistics for tables...\n');

% Loading parameters and model's solutions:
outputfile=sprintf('%s/parameters_model.mat',inputfolder); load(outputfile);
outputfile=sprintf('%s/fathers.mat',inputfolder); load(outputfile);
outputfile=sprintf('%s/sons.mat',inputfolder); load(outputfile);
load(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc));

j1_ind_fat=matrix_indexes_father(:,1);
j2_ind_fat=matrix_indexes_father(:,2);
j3_ind_fat=matrix_indexes_father(:,3);

j1_ind_son=matrix_indexes_son(:,1);
j2_ind_son=matrix_indexes_son(:,2);
j3_ind_son=matrix_indexes_son(:,3);
j4_ind_son=matrix_indexes_son(:,4);
j5_ind_son=matrix_indexes_son(:,5);
j6_ind_son=matrix_indexes_son(:,6);
j7_ind_son=matrix_indexes_son(:,7);
j8_ind_son=matrix_indexes_son(:,8);
j9_ind_son=matrix_indexes_son(:,9);
j10_ind_son=matrix_indexes_son(:,10);
j11_ind_son=matrix_indexes_son(:,11);
j12_ind_son=matrix_indexes_son(:,12);
j13_ind_son=matrix_indexes_son(:,13);
j14_ind_son=matrix_indexes_son(:,14);

% Total sorting of baseline
net_match_son=j2_ind_son.*(j12_ind_son==2); %same occ of father and father employed
adv_match_son=(j1_ind_son<=2); %son matched in advantage
pref_match_son=(j1_ind_son==1 | j1_ind_son==3);
adv_match_fat=(j1_ind_fat<=2); %father matched in advantage
pref_match_fat=(j1_ind_fat==1 | j1_ind_fat==3);
follower=(j2_ind_son==1);
follower_fat_emp=follower.*(j12_ind_son==2);
mover_fat_emp=(1-follower).*(j12_ind_son==2);

share_net_match_son=sum(net_match_son.*(e_state_sons'))/sum(e_state_sons);
share_adv_match_son=sum(adv_match_son.*(e_state_sons'))/sum(e_state_sons);
share_pref_match_son=sum(pref_match_son.*(e_state_sons'))/sum(e_state_sons);
share_net_match_son_foll=sum(net_match_son.*(e_state_sons').*(follower==1))/sum(e_state_sons.*(follower'==1));
share_adv_match_son_foll=sum(adv_match_son.*(e_state_sons').*(follower==1))/sum(e_state_sons.*(follower'==1));
share_pref_match_son_foll=sum(pref_match_son.*(e_state_sons').*(follower==1))/sum(e_state_sons.*(follower'==1));
share_net_match_son_move=sum(net_match_son.*(e_state_sons').*(follower==0))/sum(e_state_sons.*(follower'==0));
share_adv_match_son_move=sum(adv_match_son.*(e_state_sons').*(follower==0))/sum(e_state_sons.*(follower'==0));
share_pref_match_son_move=sum(pref_match_son.*(e_state_sons').*(follower==0))/sum(e_state_sons.*(follower'==0));
share_net = [share_net_match_son share_net_match_son_foll share_net_match_son_move];
share_adv = [share_adv_match_son share_adv_match_son_foll share_adv_match_son_move];
share_pref = [share_pref_match_son share_pref_match_son_foll share_pref_match_son_move];
share_adv_match_fat=sum(adv_match_fat.*(e_state_fat'))/sum(e_state_fat);
share_pref_match_fat=sum(pref_match_fat.*(e_state_fat'))/sum(e_state_fat);

% persistence
occ_pers =((sum(follower.*(e_state_sons)')/(sum(e_state_sons))))*n_occ;   % Share of followers * number of occupations

% welfare
welfare =sum((e_state_sons').*(pref_son+productivity_son) + (u_state_sons').*b - kappa.*(u_state_sons').*theta) + ...
         sum((e_state_fat').*(pref_father+productivity_father) + (u_state_fat').*b - kappa.*(u_state_fat').*theta);
fprintf('Total Prod = %g \n',sum((e_state_sons').*(productivity_son)));
fprintf('Total Pref = %g \n',sum((e_state_sons').*(pref_son)));
fprintf('Total B    = %g \n',sum((u_state_sons').*b));
fprintf('Total Cost = %g \n',sum((u_state_sons').*(kappa.*theta)));

% sorting adv (son)
sorting_adv=sum(adv_match_son.*e_state_sons')/sum(e_state_sons);
% sorting pref (son)
sorting_pref=sum(pref_match_son.*e_state_sons')/sum(e_state_sons);
% sorting adv (fat)
sorting_adv_fat=sum(adv_match_fat.*e_state_fat')/sum(e_state_fat);
% sorting pref (fat)
sorting_pref_fat=sum(pref_match_fat.*e_state_fat')/sum(e_state_fat);
% output per worker
output_per_work_son=sum((productivity_son+tau_policy).*e_state_sons')/sum(e_state_sons);
output_per_work_fat=sum((productivity_father+tau_policy).*e_state_fat')/sum(e_state_fat);
output_per_work=(output_per_work_son*sum(e_state_sons)+output_per_work_fat*sum(e_state_fat))/(sum(e_state_sons)+sum(e_state_fat));
%output_per_work=output_per_work_son;
total_output=output_per_work*(sum(e_state_sons)+sum(e_state_fat))/2;

% wage variance
log_w_son=log(w_son);
log_w_fat=log(w_father);
wage_mean_son=(e_state_sons*log_w_son)/sum(e_state_sons);
wage_variance_son=sum(((log_w_son-wage_mean_son).^2).*(e_state_sons'))/sum(e_state_sons);
wage_mean_fat=(e_state_fat*log_w_fat)/sum(e_state_fat);
wage_variance_fat=sum(((log_w_fat-wage_mean_fat).^2).*(e_state_fat'))/sum(e_state_fat);
wage_variance=wage_variance_son*sum(e_state_sons)+wage_variance_fat*sum(e_state_fat)/...
    (sum(e_state_sons) + sum(e_state_fat));

% welfare variance
welfare_followers=(e_state_sons*(W_son.*follower) + u_state_sons*(U_son.*follower))/(sum(e_state_sons(follower))+sum(u_state_sons(follower)));
welfare_movers=(e_state_sons*(W_son.*(1-follower)) + u_state_sons*(U_son.*(1-follower)))/ ...
    (sum(e_state_sons(follower==0))+sum(u_state_sons(follower==0)));

welf_mean_son=(e_state_sons*W_son+u_state_sons*U_son)/(sum(e_state_sons)+sum(u_state_sons));
welf_variance_son=sum(((W_son-welf_mean_son).^2).*(e_state_sons') + ((U_son-welf_mean_son).^2).*(u_state_sons'))/(sum(e_state_sons)+sum(u_state_sons));
CV_welfare_son=sqrt(welf_variance_son)/welf_mean_son;
welf_mean_fat=(e_state_fat*W_father+u_state_fat*U_father)/(sum(e_state_fat)+sum(u_state_fat));
welf_variance_fat=sum(((W_father-welf_mean_fat).^2).*(e_state_fat') + ((U_father-welf_mean_fat).^2).*(u_state_fat'))/(sum(e_state_fat)+sum(u_state_fat));
CV_welfare_fat=sqrt(welf_variance_fat)/welf_mean_fat;
CV_welfare=(CV_welfare_son+CV_welfare_fat)/2;
% unemp. rate
u_rate=sum(u_state_sons)/(sum(u_state_sons)+sum(e_state_sons));
% Average UE rate:
avg_JF=sum(jobfind_son.*u_state_sons')/sum(u_state_sons);
% Average EU rate:
avg_JS=sum((probleave_emp_son + (1-probleave_emp_son)*delta).*e_state_sons')/sum(e_state_sons);

wage_mean_son_foll=e_state_sons((follower==1))*log_w_son((follower==1))/sum(e_state_sons((follower==1)));
wage_mean_son_move=e_state_sons((follower==0))*log_w_son((follower==0))/sum(e_state_sons((follower==0)));
u_rate_foll=sum(u_state_sons(find(follower==1)))/(sum(u_state_sons(find(follower==1)))+sum(e_state_sons(find(follower==1))));
u_rate_move=sum(u_state_sons(find(follower==0)))/(sum(u_state_sons(find(follower==0)))+sum(e_state_sons(find(follower==0))));

save('base_cal/statistics_exper.mat');

end