%function [occ_pers_vec, welfare_vec, sorting_vec, u_rate_vec] = decomp(inputfolder)
clear
%% BASELINE
%load calibration_results_9occ_restricted.mat paramout
load results/calibration_results_3hc_9occ_restricted.mat paramout
baseline(1:2)=paramout(1:2);
baseline(3)=0;
baseline(4)=paramout(3);
baseline(5)=1/9;
baseline(6:12)=paramout(4:10);

   %Experiments one after the other
for nexp = 1:2
    if nexp == 1, param=baseline; %baseline case
    elseif nexp == 2
        %% COUNTERFACTUAL 2 (NO COMP.ADV. TRANSMISSION)
        param = baseline;
        param(4)=1/n_occ;
    end    
    write_parameters(param)
    model_sons;
    
    compute_all_statistics;
    load('base_cal/statistics_exper.mat');
    
    %Here we define different variables for each experiment
    if nexp == 1
        sort_base= [share_adv_match_fat, 0, 0; share_pref_match_fat, 0, 0;...
            share_net; share_adv; share_pref; ...
            wage_mean_son, wage_mean_son_foll, wage_mean_son_move; ...
            u_rate, u_rate_foll, u_rate_move];
    end
    
    occ_pers_vec(nexp)=occ_pers;
    welfare_vec(nexp)=welfare;
    total_output_vec(nexp)=total_output;
    sorting_adv_son_vec(nexp)=sorting_adv;
    sorting_pref_son_vec(nexp)=sorting_pref;
    sorting_adv_fat_vec(nexp)=sorting_adv_fat;
    sorting_pref_fat_vec(nexp)=sorting_pref_fat;
    output_per_work_vec(nexp)=output_per_work;
    wage_variance_vec(nexp)=wage_variance;
    welfare_variance_vec(nexp)=CV_welfare;
    u_rate_vec(nexp)=u_rate;
    avg_JF_vec(nexp)=avg_JF;
    avg_JS_vec(nexp)=avg_JS;
    theta_vec(nexp)=max(theta);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

occ_pers_vec_rel_change(2)= 100*(occ_pers_vec(2)-occ_pers_vec(1))/(occ_pers_vec(1)-1);
welfare_vec_rel_change(2)= 100*(welfare_vec(2)-welfare_vec(1))/(welfare_vec(1));
output_rel_change(2)=(total_output_vec(2)-total_output_vec(1))/total_output_vec(1);
output_per_work_vec_rel_change(2)=(output_per_work_vec(2))/(output_per_work_vec(1));
output_per_work_vec_rel_change(1)=1;  
wage_variance_vec_rel_change(2)=100*(wage_variance_vec(2)-wage_variance_vec(1))/(wage_variance_vec(1));
wage_variance_vec_rel_change(1)=wage_variance_vec(1);
welfare_variance_vec_rel_change(2)=100*(welfare_variance_vec(2)-welfare_variance_vec(1))/(welfare_variance_vec(1));
welfare_variance_vec_rel_change(1)=welfare_variance_vec(1);
u_rate_vec_rel_change(2)=100*(u_rate_vec(2)-u_rate_vec(1))/(u_rate_vec(1));
u_rate_vec_rel_change(1)=u_rate_vec(1);
avg_JF_vec_rel_change(2)=100*(avg_JF_vec(2)-avg_JF_vec(1))/(avg_JF_vec(1));
avg_JF_vec_rel_change(1)=avg_JF_vec(1);
avg_JS_vec_rel_change(2)=100*(avg_JS_vec(2)-avg_JS_vec(1))/(avg_JS_vec(1));
avg_JS_vec_rel_change(1)=avg_JS_vec(1);
theta_vec_rel_change(2)=100*(theta_vec(2)-theta_vec(1))/(theta_vec(1));
theta_vec_rel_change(1)=theta_vec(1);

fprintf('Sorting under baseline:')
sort_base

fprintf('Decomposition')
exper = [occ_pers_vec; occ_pers_vec_rel_change; ...
 %welfare_vec;
 welfare_vec_rel_change; output_rel_change;...
 sorting_adv_son_vec; sorting_pref_son_vec; ...
 sorting_adv_fat_vec; sorting_pref_fat_vec; ...
 output_per_work_vec_rel_change; wage_variance_vec_rel_change; ...
 welfare_variance_vec_rel_change; u_rate_vec_rel_change; ...
 avg_JF_vec_rel_change; avg_JS_vec_rel_change; ...
 theta_vec_rel_change]

save experiments_restricted.mat sort_base exper

%% Export to Latex:
% rows={'Sorting along comparative advantage (fathers)';'Sorting along preferences (fathers)';'Sorting along parental networks (sons)';...
%     'Sorting along comparative advantage (sons)';'Sorting along preferences (sons)'; ...
%     'Average log wage (sons)';'Average unemployment rate (sons)'};
% clear input
% for j=1:size(sort_base,2)
%    input.data(:,j)=sort_base(:,j); 
% end
% T=table(sort_base,'RowNames',rows);
% input.data = T; 
% input.dataFormat = {'%.3f'};
% input.makeCompleteLatexDocument = 0;
% input.numTable = 1;   % number of table (for this file)
% input.tableBorders = 0;
% input.tableSpace = 1;
% input.tableCaption = 'Model-simulated data under the {\\textbf{Restricted Calibration}}: Occupational sorting and summary statistics. Sorting is defined as the fraction of workers whose occupation is aligned with their comparative advantage/preferences/parental network.';
% input.tableLabel='table_sorting_restricted';
% input.headerText='';
% 
% input.yesSpace = [1:length(sort_base)+1];
% %input.yesSpace(3)= 0; %switch off space after row 1 (it has to be "+2")
% input.yesBrackets = zeros(1,length(sort_base)+1);
% %input.yesBrackets(3)= 3; % switch on where you want brackets
% %input.yesBrackets(5)= 5; % switch on where you want brackets
% latex = latexTable(input);
% % save LaTex code as file
% fid=fopen('tables/table_sort_restricted.tex','w');
% [nrows,ncols] = size(latex);
% for row = 1:nrows
%     fprintf(fid,'%s\n',latex{row,:});
% end
% fclose(fid);


rows={'Occupational Persistence';'($\Delta\%$ from baseline)';'Welfare ($\Delta\% $ from baseline)';'Output ($\Delta\% $ from baseline)';'Sorting along comparative advantage (sons)';'Sorting along preferences (sons)'; ...
    'Sorting along comparative advantage (fathers)';'Sorting along preferences (fathers)'; ...
    'Output per worker (=1 in baseline)';'Log Wage Variance ($\Delta\% $ from baseline)';'Welfare CV ($\Delta\% $ from baseline)';'Unemployment Rate ($\Delta\% $ from baseline)';...
    'Average UE Rate ($\Delta\% $ from baseline)'; 'Average EU Rate ($\Delta\% $ from baseline)'; 'Equilibrium Tightness'};
clear input
for j=1:size(exper,2)
   input.data(:,j)=exper(:,j); 
end
T=table(exper,'RowNames',rows);
input.data = T; 
input.dataFormat = {'%.3f'};
input.makeCompleteLatexDocument = 0;
input.numTable = 2;   % number of table (for this file)
input.tableBorders = 0;
input.tableSpace = 1;
input.tableCaption = 'Occupational Persistence Decomposition and Welfare Analysis (Restricted Model).';
input.tableLabel='table_decomp_restricted';
input.headerText='\hline\hline  & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} \\ \multicolumn{1}{l}{\textbf{No parental net.} \hspace{2.9cm}($\xi=0$)} & n.a. & n.a. \\ \multicolumn{1}{l}{\textbf{No comp. adv. trans.}} ($\rho_\tau=1/O$)  & - & $\checkmark$ \\ \multicolumn{1}{l}{\textbf{No pref. trans.}} ($\rho_\phi=1/O$)  & n.a. & n.a. \\  \hline';
input.yesSpace = [1:length(exper)+1];
input.yesSpace(3)= 0; %switch off space after row 1 (it has to be "+2")
input.yesBrackets = zeros(1,length(exper)+1);

input.yesBrackets(3)= 3; % switch on where you want brackets
input.yesBrackets(4)= 4; % switch on where you want brackets
input.yesBrackets(5)= 5;
for j=11:16
   input.yesBrackets(j)= j; % switch on where you want brackets
end
latex = latexTable(input);
% save LaTex code as file
fid=fopen('tables/table_exper_restricted.tex','w');
[nrows,ncols] = size(latex);
for row = 1:nrows
    fprintf(fid,'%s\n',latex{row,:});
end
fclose(fid);
