function [res_k,mom] = figure_identification(numcores,alreadydone)

if nargin < 1, numcores=1; end
if nargin < 2, alreadydone=0; end

if alreadydone == 0
    
    if numcores > 1, POOL = parpool('local',numcores,'IdleTimeout',99999); folderout=100;
    else folderout=1; end
    
    load results/calibration_results_3hc_9occ.mat paramout
    %Build a table with changes in all moments when all parameters change
    
    params_totry=zeros(12,12);
    res_k=zeros(12,1);
    mom=zeros(12,12);
    
    [res_base,mom_base]=doit(paramout);
    for jj=1:2
        if jj == 1, change_par=1.01;
        elseif jj==2, change_par=0.99; end
        
        for k=1:12
            params_totry(:,k)=paramout;
            params_totry(k,k)=paramout(k).*(change_par); %change parameter by +15%
        end
        
        if numcores > 1
            parfor k=1:12
                [res_k(k),mom(:,k)]=doit(params_totry(:,k),folderout);
            end
        else
            for k=1:12
                [res_k(k),mom(:,k)]=doit(params_totry(:,k));
            end
        end
        if jj==1, momplus=mom;
        elseif jj==2, momminus=mom; end
    end
    
    momplus=diag(momplus);
    momminus=diag(momminus);
    
    momplus=(momplus-mom_base);
    momminus=(momminus-mom_base);
    
    %rearranging moments to make them correspond to their parameters
    mom_plus_toshow=(momplus);
    mom_minus_toshow=(momminus);
    mom_plus_toshow(4)=momplus(5);      mom_minus_toshow(4)=momminus(5);
    mom_plus_toshow(5)=momplus(4);      mom_minus_toshow(5)=momminus(4);
    mom_plus_toshow(6)=momplus(8);      mom_minus_toshow(6)=momminus(8);
    mom_plus_toshow(7)=momplus(6);      mom_minus_toshow(7)=momminus(6);
    mom_plus_toshow(8)=momplus(7);      mom_minus_toshow(8)=momminus(7);
    mom_plus_toshow(11)=momplus(9);     mom_minus_toshow(11)=momminus(9);
    mom_plus_toshow(9)=momplus(11);     mom_minus_toshow(9)=momminus(11);
    mom_plus_toshow(10)=momplus(12);    mom_minus_toshow(10)=momminus(12);
    mom_plus_toshow(12)=momplus(10);    mom_minus_toshow(12)=momminus(10);
    
    save results/moments_identification_graph.mat mom_plus_toshow mom_minus_toshow
    
    if numcores > 1, delete(POOL); end
    
end

load results/moments_identification_graph.mat mom_plus_toshow mom_minus_toshow

fig_id1=figure('Color','white');
bars_used=barh((1:8)',[mom_plus_toshow(1:8) mom_minus_toshow(1:8)],'stacked','BaseValue',0); legend('+1%','- 1%','Location','northeast');
bars_used(1).FaceColor='red';
bars_used(2).FaceColor='cyan';
ax=gca;
ax.TickLabelInterpreter='latex';
ax.XLim = [-0.2 0.2];
ax.FontSize = 14;
yticklabels({'$\kappa$','$\delta$','$\xi$','$\rho_\phi$','$\rho_\tau$','$\sigma_\epsilon$',...
    '$\hat{\phi}$','$\hat{\tau}$'});
xlabel('Relative change in moment');
saveas(fig_id1,'figures/identification_figure_part1.eps','eps');

fig_id2=figure('Color','white');
bars_used=barh((1:4)',[mom_plus_toshow(9:12) mom_minus_toshow(9:12)],'stacked','BaseValue',0); legend('+1%','- 1%','Location','northeast');
bars_used(1).FaceColor='red';
bars_used(2).FaceColor='cyan';
ax=gca;
ax.TickLabelInterpreter='latex';
ax.FontSize = 14;
yticklabels({'$\hat{n}$','$b$','$p_h^-$','$p_n^-$'});
xlabel('Relative change in moment');
saveas(fig_id2,'figures/identification_figure_part2.eps','eps');

end