function [ res ] = table_calibration_restricted( alreadydone )

%alreadydone = 0: compute whole model, =1: compute only final moments, =2: load already-computed moments

if nargin < 1, alreadydone=0; end   %By default nothing is computed

load results/calibration_results_3hc_9occ_restricted.mat paramout
param(1:2)=paramout(1:2);
param(3)=0;
param(4)=paramout(3);
param(5)=1/9;
param(6:12)=paramout(4:10);

%This line is for my folder name
fileid2=fopen('tables/table_calibration_restricted.tex','w+');

load base_cal/targets.mat    %here targets are loaded

%This part below generates the moments for the table
if alreadydone == 1, gen_moments_exact_NEW_STATE;
elseif alreadydone == 0
    write_parameters(param);
    model_sons;
    gen_moments;
end

load base_cal/moments.mat moments   %here moments are loaded

fprintf(fileid2,' \\begin{landscape}  \n');
fprintf(fileid2,'  \\begin{table}[htbp]  \n');
fprintf(fileid2,'  \\begin{small}    \n');
fprintf(fileid2,'  \\centering    \n');
fprintf(fileid2,'  \\begin{tabular}{c l c l c c c} \\hline\\hline   \n');
fprintf(fileid2,' \\multicolumn{1}{c}{\\textbf{Parameter}} & \\multicolumn{1}{c}{\\textbf{Description}} & \\multicolumn{1}{c}{\\textbf{Value}} & \\multicolumn{1}{c}{\\textbf{Target/Source}} & \\multicolumn{1}{c}{\\textbf{Data}} & \\multicolumn{1}{c}{\\textbf{Model}} \\\\ \\hline  \n');
fprintf(fileid2,' \\multicolumn{2}{l}{\\textbf{Intergenerational Transmission}} \\\\  \n');
fprintf(fileid2,' $\\xi$ & Transmission of Networks &  0$^*$ & JF premium of followers (BHPS) & [%9.3f] & %9.3f \\\\  \n',targets(3),moments(3));
fprintf(fileid2,' $\\rho_{\\tau}$ & Transmission of Comparative Advantage & %9.3f & Difference in Share of Followers by Father''s wage (BHPS) & %9.3f & %9.3f \\\\  \n',param(4),targets(5),moments(5));
fprintf(fileid2,' $\\rho_{\\phi}$ & Transmission of Preferences & %9.3f$^*$ & Interg. Occupational Persistence (Lik. Ratio, BHPS) & %9.3f & %9.3f \\\\  \n',1/9,targets(4),moments(4));
fprintf(fileid2,' \\hline  \n');
fprintf(fileid2,' \\multicolumn{2}{l}{\\textbf{Heterogeneity and Laws of Motions}} \\\\  \n');
fprintf(fileid2,' $\\hat{h_1}$ & HC premium after 5 years & 0.198 & Average occupational tenure returns after 5 years (BHPS) & - & - \\\\  \n');
fprintf(fileid2,' $\\hat{h_2}$ & HC premium after 10 years & 0.299 & Average occupational tenure returns after 10 years (BHPS) & - & - \\\\ \n');
fprintf(fileid2,' $\\hat{n}$ & Networks premium &  %9.3f & Share of jobs found through contacts (\\cite{pellizzari2010friends}) & %9.3f & %9.3f  \\\\  \n',param(9),targets(11),moments(11));
fprintf(fileid2,' $\\hat{\\tau}$ & Comparative Advantage premium & %9.3f & Within--occupation log wage variance (BHPS) & %9.3f & %9.3f \\\\  \n',param(8),targets(7),moments(7));
fprintf(fileid2,' $\\bar{\\phi}$ & Baseline preference for jobs & 0 & Normalization & - & - \\\\  \n');
fprintf(fileid2,' $\\hat{\\phi}$ & Preference premium & %9.3f  & Wage discount of followers (BHPS) & [%9.3f] & %9.3f  \\\\  \n',param(7),targets(6),moments(6));
fprintf(fileid2,' $p^+_h$ & Probability of accumulating HC (employed) & 0.0166 & Average occupational tenure returns after 5 years (BHPS) & 0.260 & 0.260 \\\\  \n');
fprintf(fileid2,' $p^-_h$ & Probability of losing HC (unemployed) & %9.3f & Average wage discount after unemp. (\\cite{arulampalam2001unemployment}) & %9.3f & %9.3f  \\\\  \n',param(11),-targets(9),-moments(9));
fprintf(fileid2,' $p^+_n$ & Probability of accumulating networks (employed) & %9.3f & Regression of JF rate vs. past occupational tenure (BHPS) & 0.008 & 0.008 \\\\  \n',(0.008)/(0.1251*param(9)*12));
fprintf(fileid2,' $p^-_n$ & Probability of losing networks (unemployed) & %9.3f & JF rate--unemployment duration profile (see text, BHPS) & %9.3f & %9.3f \\\\  \n',param(12),targets(10),moments(10));
fprintf(fileid2,' $\\sigma$ & Standard deviation of preference shocks  & %9.3f & Occupational change rate, after U spell (monthly, BHPS) & %9.3f & %9.3f \\\\ \\hline  \n',param(6),targets(8),moments(8));
fprintf(fileid2,' \\multicolumn{2}{l}{\\textbf{Environment}} \\\\  \n');
fprintf(fileid2,' $O$ & Number of occupations & 9 & 1-digit SOC aggregation & - & - \\\\  \n');
fprintf(fileid2,' $\\kappa$ & Vacancy posting cost & %9.3f & Average UE rate (monthly, BHPS) & %9.3f & %9.3f \\\\  \n',param(1),targets(1),moments(1));
fprintf(fileid2,' $\\delta$ & Exogenous separation rate & %9.3f & Average EU rate (monthly, BHPS) & %9.3f & %9.3f \\\\  \n',param(2),targets(2),moments(2));
fprintf(fileid2,' $\\beta$ & Discount factor & 0.9966 & From literature & - & - \\\\  \n');
fprintf(fileid2,' $\\zeta$ & Age shock & 0.00416 & Average length of worklife: 20 (young) + 20 (old) years & 40 & 40 \\\\  \n');
fprintf(fileid2,' $ b $ & Unemployment benefit & %9.3f & Average replacement rate (OECD) & %9.3f & %9.3f \\\\  \n',param(10),targets(12),moments(12));
fprintf(fileid2,' $\\chi $ & Surplus sharing rule & 0.7 & Normalization & - & - \\\\  \n');
fprintf(fileid2,' $ A $ & TFP parameter of matching function & 0.1 & Normalization & - & - \\\\  \n');
fprintf(fileid2,' $ \\gamma $ & Elasticity of matching function w.r.t. unemp. & 0.5 & Petrongolo and Pissarides \\citeyearpar{petrongolo2001looking} & - & - \\\\ \\hline  \n');
fprintf(fileid2,' \\end{tabular}  \n');
fprintf(fileid2,' \\caption{Calibration Results, Restricted Model ($^*$ = restricted parameters; [] = non-targeted moments)}  \n');
fprintf(fileid2,' \\label{table_calibration_restricted}  \n');
fprintf(fileid2,' \\end{small}  \n');
fprintf(fileid2,' \\end{table}  \n');
fprintf(fileid2,' \\end{landscape}  \n');
fclose(fileid2);


res=0; %returns success value
end

