function [mom] = gen_moments(inputfolder)
maxNumCompThreads(8);

starttic=tic;
fprintf('Computing population moments...');

% Loading parameters and model's solutions:
if nargin < 1
    %Parameters loaded here
    load base_cal/parameters_model.mat 
    % Load fathers' problem:
    load base_cal/fathers.mat
    load base_cal/sons.mat
    load(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc));
    [trans_newson_U,trans_newson_E]=trans_newson_gen();
else
    paramstring=sprintf('%g\\parameters_model.mat',inputfolder); load(paramstring);
    fatherstring=sprintf('%g\\fathers.mat',inputfolder); load(fatherstring);
    sons_string=sprintf('%g\\sons.mat',inputfolder); load(sons_string);
    load(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc));
    [trans_newson_U,trans_newson_E]=trans_newson_gen(inputfolder);
end
num_moments=16;
moments=zeros(num_moments,1);

%ORDER OF VARIABLES
% 1) POSITION of fat (1-5)
% 2) HC of fat (1-2)
% 3) NET of fat (1-2)

j1_ind_fat=matrix_indexes_father(:,1);
j2_ind_fat=matrix_indexes_father(:,2);
j3_ind_fat=matrix_indexes_father(:,3);

%ORDER OF VARIABLES
% 1) POSITION of son (1-5)
% 2) FOLLOWER (dummy)
% 3) STATE of father (1-20): position of father + HC of fat + NET of fat
% 4) ADV. of son == ADV. of fat (dummy)
% 5) PREF. of son == PREF. of fat (dummy)
% 6) ADV. of son == PREF. of fat (dummy)
% 7) PREF. of son == ADV. of fat (dummy)
% 8) OCC. of fat == ADV. of son (dummy)
% 9) OCC. of fat == PREF. of son (dummy)
% 10) OCC. of son == ADV. of fat (dummy)
% 11) OCC. of son == PREF. of fat (dummy)
% 12) E.S. of fat (1-2)
% 13) HC of son (1-2)
% 14) NET of son (1-2)

j1_ind_son=matrix_indexes_son(:,1);
j2_ind_son=matrix_indexes_son(:,2);
j3_ind_son=matrix_indexes_son(:,3);
j4_ind_son=matrix_indexes_son(:,4);
j5_ind_son=matrix_indexes_son(:,5);
j6_ind_son=matrix_indexes_son(:,6);
j7_ind_son=matrix_indexes_son(:,7);
j8_ind_son=matrix_indexes_son(:,8);
j9_ind_son=matrix_indexes_son(:,9);
j10_ind_son=matrix_indexes_son(:,10);
j11_ind_son=matrix_indexes_son(:,11);
j12_ind_son=matrix_indexes_son(:,12);
j13_ind_son=matrix_indexes_son(:,13);
j14_ind_son=matrix_indexes_son(:,14);


%% MOMENTS:
% 1) Average UE rate:
avg_JF=sum(jobfind_son.*u_state_sons')/sum(u_state_sons);  

% 2) Average EU rate:
avg_JS=sum((probleave_emp_son + (1-probleave_emp_son)*delta).*e_state_sons')/sum(e_state_sons);    

% 3) JF premium for followers:   
follower=(matrix_indexes_son(:,2)==1);   
JF_prem=sum(jobfind_son.*u_state_sons'.*follower)/sum(u_state_sons'.*follower) - ...
        sum(jobfind_son.*u_state_sons'.*(1-follower))/sum(u_state_sons'.*(1-follower));   
    
% 4) Occupational Persistence (Lik. Ratio):      
occ_pers=((sum(follower.*(e_state_sons)')/(sum(e_state_sons))))*n_occ;   % Share of followers * number of occupations

log_w_son=log(w_son);     
log_w_fat=log(w_father);     

% 5) Wage Correlations (Intergenerational) among followers MINUS Correlation among movers:
 log_w_fat_changed=(log_w_fat(matrix_indexes_son(:,3)).*(j12_ind_son-1));   % Zeroes the wages of unemployed fathers
 mean_w_fat=(log_w_fat_changed'*(e_state_sons'.*(j12_ind_son-1))/sum(e_state_sons'.*(j12_ind_son-1)));

 occ_pers_rich=((sum(follower.*((j12_ind_son-1)'.*e_state_sons.*(log_w_fat_changed>mean_w_fat)')')/(sum((j12_ind_son-1).*e_state_sons'.*(log_w_fat_changed>mean_w_fat)))));   % Share of followers 
 occ_pers_poor=((sum(follower.*((j12_ind_son-1)'.*e_state_sons.*(log_w_fat_changed<mean_w_fat)')')/(sum((j12_ind_son-1).*e_state_sons'.*(log_w_fat_changed<mean_w_fat)))));   % Share of followers 
 occ_pers_diff=occ_pers_rich-occ_pers_poor;

% 6) Wage discount of followers:
wage_mean_son_foll=e_state_sons*(log_w_son.*follower.*(j12_ind_son==2))/sum(e_state_sons'.*follower.*(j12_ind_son==2));
wage_mean_son_move=e_state_sons*(log_w_son.*(1-follower).*(j12_ind_son==2))/sum(e_state_sons'.*(1-follower).*(j12_ind_son==2));
wage_disc=-wage_mean_son_foll+wage_mean_son_move;

% 7) Wage variance within occupations
wage_mean_son=e_state_sons*log_w_son/sum(e_state_sons);
wage_variance_son=sum(((log_w_son-wage_mean_son).^2).*(e_state_sons'))/sum(e_state_sons);
wage_mean_fat=e_state_fat*log_w_fat/sum(e_state_fat);
wage_variance_fat=sum(((log_w_fat-wage_mean_fat).^2).*(e_state_fat'))/sum(e_state_fat);
wage_variance=wage_variance_son*sum(e_state_sons)+wage_variance_fat*sum(e_state_fat)/...
              (sum(e_state_sons) + sum(e_state_fat));
wage_disp=sqrt(wage_variance);
             
% 13) Share of jobs found through networks:
jobs_net=(sum((net_son-1).*(u_state_sons').*jobfind_son)/sum((net_son).*(u_state_sons').*jobfind_son)*sum(u_state_sons) + ...
         sum((net_father-1).*(u_state_fat').*jobfind_fat)/sum((net_father).*(u_state_fat').*jobfind_fat)*sum(u_state_fat)) / (sum(u_state_fat) + sum(u_state_sons));
     
% 14) Unemployment benefits:
wage_mean= (e_state_sons*w_son + e_state_fat*w_father)/(sum(e_state_sons)+sum(e_state_fat));
unemp_benef = param(10)/wage_mean;

%These are useful for later - measure of "just separated" people
measure_justseparated_sons=(e_state_sons*total_trans_omega_E).*(delta + probleave_emp_son'.*(1-delta));   
measure_justseparated_fat=(e_state_fat*total_trans_father_E).*(delta + probleave_emp_fat'.*(1-delta)); 

measure_left_son=speye(statesize_son)*trans_occ_son;
measure_left_fat=speye(statesize_fat)*trans_occ_fat;
all_trans_son=sparse(statesize_son,statesize_son);
all_trans_fat=sparse(statesize_fat,statesize_fat);

total_trans_omega_U_bsx=total_trans_omega_U';
for k=1:statesize_son
    total_trans_omega_U_bsx(:,k)=total_trans_omega_U_bsx(:,k).*(1-jobfind_son(k));
end
total_trans_omega_U_bsx=total_trans_omega_U_bsx';
TRANS_FOR_LATER=total_trans_omega_U*trans_occ_son;

dist_left=100;
jf_over_dur=zeros(2,1);
jobfinding_follower=0;
jobfinding_mover=0;
totalmonths_taken=sparse(statesize_son,statesize_son);
totalmonths_taken_follower=0;
totalmonths_taken_mover=0;
tm_taken_follower2=0;
tm_taken_mover2=0;
iter=0;
%This code is also used to compute JF over U duration
while dist_left > 10^(-6)
    iter=iter+1;
    %This matrix computes the next period measure of people transiting and
    %changing occupations
    trans_now_son=measure_left_son.*jobfind_son';
    trans_now_fat=measure_left_fat.*jobfind_fat';
       
    if iter <= numel(jf_over_dur)
        jf_over_dur(iter)=sum(measure_justseparated_sons*trans_now_son)/sum((measure_justseparated_sons*measure_left_son));
    end
       
    jobfinding_follower=jobfinding_follower+sum(sum(measure_justseparated_sons*trans_now_son.*follower'));
    jobfinding_mover=jobfinding_mover+sum(sum(measure_justseparated_sons*trans_now_son.*(1-follower'))); 
          
    %1b) accumulate all past measure of people transiting - not necessary anymore?
    all_trans_son=all_trans_son+trans_now_son;
    all_trans_fat=all_trans_fat+trans_now_fat;
    %clear trans_now_son trans_now_fat
    
    %how many months did they take? used for JF computation
    tm_taken_follower2=tm_taken_follower2+sum(sum(measure_justseparated_sons*measure_left_son.*(follower')));
    tm_taken_mover2=tm_taken_mover2+sum(sum(measure_justseparated_sons*measure_left_son.*(1-follower')));
        
    %2) measure of people changing for next period
    measure_left_son=measure_left_son*total_trans_omega_U_bsx*trans_occ_son;

    measure_left_fat=bsxfun(@times,1-jobfind_fat',(measure_left_fat))*total_trans_father_U*trans_occ_fat;
    
    if (mod(iter,5)==0) && (iter > 40), dist_left=max(max(abs(measure_left_son))); end
end

jf_premium_newmethod=(jobfinding_follower/tm_taken_follower2)-(jobfinding_mover/tm_taken_mover2);

prob_staying_son_new=zeros(statesize_son,1);
prob_staying_fat_new=zeros(statesize_fat,1);

prob_staying_son_new(j1_ind_son==1)=sum(all_trans_son((j1_ind_son==1),(j1_ind_son==1)),2);
prob_staying_son_new(j1_ind_son==2)=sum(all_trans_son((j1_ind_son==2),(j1_ind_son==2)),2);
prob_staying_son_new(j1_ind_son==3)=sum(all_trans_son((j1_ind_son==3),(j1_ind_son==3)),2);
maintained_hc=(j13_ind_son==2);
maintained_net=(j14_ind_son==2);
maint_hc_fat=(j2_ind_fat==2);
maint_net_fat=(j3_ind_fat==2);
fatherhasnotchanged_1=(j3_ind_son<3 & j2_ind_son==1);
fatherhasnotchanged_0=(j3_ind_son<3 & j2_ind_son==0);

prob_staying_son_new((j1_ind_son==4 & j10_ind_son==1 & j11_ind_son==0))= ...
    sum(all_trans_son((j1_ind_son==4)&(j10_ind_son==1)&(j11_ind_son==0),(j1_ind_son==4)&(j10_ind_son==1)&(j11_ind_son==0)),2);
prob_staying_son_new((j1_ind_son==4 & j10_ind_son==0 & j11_ind_son==1))= ...    
    sum(all_trans_son((j1_ind_son==4)&(j10_ind_son==0)&(j11_ind_son==1),(j1_ind_son==4)&(j10_ind_son==0)&(j11_ind_son==1)),2);
prob_staying_son_new((j1_ind_son==4 & j10_ind_son==1 & j11_ind_son==1))= ...  
    sum(all_trans_son((j1_ind_son==4)&(j10_ind_son==1)&(j11_ind_son==1),(j1_ind_son==4)&(j10_ind_son==1)&(j11_ind_son==1)),2);
prob_staying_son_new((j1_ind_son==5 & j10_ind_son==1 & j11_ind_son==0))= ...
    sum(all_trans_son((j1_ind_son==5)&(j10_ind_son==1)&(j11_ind_son==0),(j1_ind_son==5)&(j10_ind_son==1)&(j11_ind_son==0)),2);
prob_staying_son_new((j1_ind_son==5 & j10_ind_son==0 & j11_ind_son==1))= ... 
    sum(all_trans_son((j1_ind_son==5)&(j10_ind_son==0)&(j11_ind_son==1),(j1_ind_son==5)&(j10_ind_son==0)&(j11_ind_son==1)),2);
prob_staying_son_new((j1_ind_son==5 & j10_ind_son==1 & j11_ind_son==1))= ...  
    sum(all_trans_son((j1_ind_son==5)&(j10_ind_son==1)&(j11_ind_son==1),(j1_ind_son==5)&(j10_ind_son==1)&(j11_ind_son==1)),2);

indexesnow4=(j1_ind_son==4 & j10_ind_son==0 & j11_ind_son==0);
prob_staying_son_new(indexesnow4)=prob_staying_son_new(indexesnow4)+...
    sum(all_trans_son(indexesnow4,indexesnow4 & (maintained_hc+maintained_net>=1)),2);
prob_staying_son_new(indexesnow4 & fatherhasnotchanged_1)=prob_staying_son_new(indexesnow4 & fatherhasnotchanged_1) + ...
    sum(all_trans_son(indexesnow4 & fatherhasnotchanged_1,indexesnow4 & fatherhasnotchanged_1 & (maintained_hc+maintained_net==0)),2);

theresidual=indexesnow4 & fatherhasnotchanged_1==0;
prob_staying_son_new(theresidual)=prob_staying_son_new(theresidual)+... 
    sum(prob_choosing_occ(theresidual,1)./(prob_choosing_occ(theresidual,1)+sum(prob_choosing_occ(theresidual,3:end),2)).*all_trans_son(theresidual,theresidual & (maintained_hc+maintained_net==0)),2);


indexesnow5=(j1_ind_son==5 & j10_ind_son==0 & j11_ind_son==0);
prob_staying_son_new(indexesnow5)=prob_staying_son_new(indexesnow5)+...
    sum(all_trans_son(indexesnow5,indexesnow5 & (maintained_hc+maintained_net>=1)),2);
prob_staying_son_new(indexesnow5 & fatherhasnotchanged_1)=prob_staying_son_new(indexesnow5 & fatherhasnotchanged_1) + ...
    sum(all_trans_son(indexesnow5 & fatherhasnotchanged_1,indexesnow5 & fatherhasnotchanged_1 & (maintained_hc+maintained_net==0)),2);

theresidual=indexesnow5 & fatherhasnotchanged_1==0;
prob_staying_son_new(theresidual)=prob_staying_son_new(theresidual)+... 
    sum(prob_choosing_occ(theresidual,1)./(prob_choosing_occ(theresidual,1)+sum(prob_choosing_occ(theresidual,4:end),2)).* ...
    all_trans_son(theresidual,theresidual & (maintained_hc+maintained_net==0)),2);

%TRANSITION OF FATHERS
prob_staying_fat_new(j1_ind_fat==1)=sum(all_trans_fat((j1_ind_fat==1),(j1_ind_fat==1)),2);
prob_staying_fat_new(j1_ind_fat==2)=sum(all_trans_fat((j1_ind_fat==2),(j1_ind_fat==2)),2);
prob_staying_fat_new(j1_ind_fat==3)=sum(all_trans_fat((j1_ind_fat==3),(j1_ind_fat==3)),2);
prob_staying_fat_new(j1_ind_fat==4)=prob_staying_fat_new(j1_ind_fat==4)+ ...
    sum(all_trans_fat((j1_ind_fat==4),(j1_ind_fat==4) & (maint_hc_fat+maint_net_fat>=1)),2);
prob_staying_fat_new(j1_ind_fat==5)=prob_staying_fat_new(j1_ind_fat==5)+ ...
    sum(all_trans_fat((j1_ind_fat==5),(j1_ind_fat==5) & (maint_hc_fat+maint_net_fat>=1)),2);

prob_staying_fat_new(j1_ind_fat==4)=prob_staying_fat_new(j1_ind_fat==4)+ ...
    sum(prob_choosing_occ_fat(4,1)./(prob_choosing_occ_fat(4,1)+sum(prob_choosing_occ_fat(4,3:end),2)).*all_trans_fat((j1_ind_fat==4),(j1_ind_fat==4) & (maint_hc_fat+maint_net_fat==0)),2);
prob_staying_fat_new(j1_ind_fat==5)=prob_staying_fat_new(j1_ind_fat==5)+ ...
    sum(prob_choosing_occ_fat(5,1)./(prob_choosing_occ_fat(5,1)+sum(prob_choosing_occ_fat(5,4:end),2)).*all_trans_fat((j1_ind_fat==5),(j1_ind_fat==5) & (maint_hc_fat+maint_net_fat==0)),2);

%new moments!
occ_change_rate= ((1-prob_staying_son_new)'*measure_justseparated_sons' + (1-prob_staying_fat_new)'*measure_justseparated_fat') / ...
                  (sum(measure_justseparated_sons)+sum(measure_justseparated_fat));
              
avg_wage_disc_after_U=-(((sum(log_w_son.*((measure_justseparated_sons')))/sum(measure_justseparated_sons)) - ...
    (sum(log_w_son.*((measure_justseparated_sons*all_trans_son)'))/sum(measure_justseparated_sons*all_trans_son))));

slopeJF_after_unemp=(jf_over_dur(1)/jf_over_dur(2));


% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%SIMULATIONS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %MOMENTS THAT REQUIRE TO ITERATE ON THE DISTRIBUTION START HERE
% %compute HC returns at different horizons
% %the logic: the simulation code just iterates on the steady state one
% %starting from newborns
% %STEP 1: compute the steady state distribution of newborns
% newborns_all=u_state_sons*trans_newson_U + e_state_sons*trans_newson_E;
% 
% T=240;
% %STEP 2: compute successive distributions of sons (who might become
% %fathers) by age!
% u_sons_now=zeros(T,statesize_son);
% u_fathers_now=zeros(T,statesize_fat);
% e_sons_now=zeros(T,statesize_son);
% e_fathers_now=zeros(T,statesize_fat);
% u_sons_now(1,:)=newborns_all;
% 
% %Useful precalculations
% probleave_emp_trans_son=probleave_emp_son';
% jf_trans=jobfind_son';
% jf_fat_trans=jobfind_fat';
% probleave_emp_trans_zeta_par=probleave_emp_trans_son.*(1-zeta_par);
% probleave_emp_trans_fat=probleave_emp_fat';
% oneminus_probleave_emp_trans_zeta_par=(1-probleave_emp_trans_son).*(1-zeta_par);
% %father's
% precalc_transU_fat=trans_occ_fat*total_trans_father_U;
% 
% for t=2:T
%     initial_ustate_fathers=(transit_to_father')*(u_sons_now(t-1,:)');
%     initial_estate_fathers=(transit_to_father')*(e_sons_now(t-1,:)');
%     
%     measure1=(((((((1-zeta_par).*u_sons_now(t-1,:))) + ...
%              (((probleave_emp_trans_zeta_par).*e_sons_now(t-1,:)))))*trans_occ_son))*total_trans_omega_U;
%          
%     measure2=((((oneminus_probleave_emp_trans_zeta_par).*e_sons_now(t-1,:))))*total_trans_omega_E;
%     %new faster method
%     measure1_fat=((1-zeta_par).*((((((u_fathers_now(t-1,:))) + ...
%         (((probleave_emp_trans_fat).*e_fathers_now(t-1,:)))))*precalc_transU_fat))) + zeta_par.*initial_ustate_fathers';
%     measure2_fat=(1-zeta_par).*((((1-probleave_emp_trans_fat).*e_fathers_now(t-1,:))*total_trans_father_E)) + ...
%         zeta_par.*initial_estate_fathers';
% 
%     u_sons_now(t,:)=(((1-jf_trans).*measure1)) + ...
%             (delta.*measure2);
%     u_fathers_now(t,:)=(((1-jf_fat_trans).*measure1_fat)) + ...
%             (delta.*measure2_fat);
%     
%     e_sons_now(t,:)=(((jf_trans).*measure1)) + ...
%             ((1-delta).*measure2);
%     e_fathers_now(t,:)=(((jf_fat_trans).*measure1_fat)) + ...
%             ((1-delta).*measure2_fat);
% end
% avg_wage_20=(sum(log_w_son.*e_sons_now(12,:)') + ...
%     sum(log_w_fat.*e_fathers_now(12,:)'))/(sum(e_sons_now(12,:))+sum(e_fathers_now(12,:)));
% avg_wage_30=(sum(log_w_son.*e_sons_now(120,:)') + ...
%     sum(log_w_fat.*e_fathers_now(120,:)'))/(sum(e_sons_now(120,:))+sum(e_fathers_now(120,:)));
% avg_wage_40=(sum(log_w_son.*e_sons_now(240,:)') + ...
%     sum(log_w_fat.*e_fathers_now(240,:)'))/(sum(e_sons_now(240,:))+sum(e_fathers_now(240,:)));
% wage_variance_20=(sum(((log_w_son-avg_wage_20).^2).*e_sons_now(12,:)') +...
%     sum(((log_w_fat-avg_wage_20).^2).*e_fathers_now(12,:)'))/(sum(e_sons_now(12,:))+sum(e_fathers_now(12,:)));
% wage_variance_30=(sum(((log_w_son-avg_wage_30).^2).*e_sons_now(120,:)')+...
%     sum(((log_w_fat-avg_wage_30).^2).*e_fathers_now(120,:)'))/(sum(e_sons_now(120,:))+sum(e_fathers_now(120,:)));
% wage_variance_40=(sum(((log_w_son-avg_wage_40).^2).*e_sons_now(240,:)') +...
%     sum(((log_w_fat-avg_wage_40).^2).*e_fathers_now(240,:)'))/(sum(e_sons_now(240,:))+sum(e_fathers_now(240,:)));
% 
% wage_gain_20_to_30=avg_wage_30-avg_wage_20;
% wage_gain_20_to_40=avg_wage_40-avg_wage_20;
% ratio_wage_variance_30_to_20=wage_variance_30/wage_variance_20;
% ratio_wage_variance_40_to_20=wage_variance_40/wage_variance_20;

%%%%%%%%%%%%%%%%%%END OF SIMULATIONS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


moments(1)=avg_JF;                  % Kappa
moments(2)=avg_JS;                  % Delta
moments(3)=jf_premium_newmethod;    %Xi      %OLD METHOD: JF_prem;                 % Xi
moments(4)=occ_pers;                % Rho_phi
moments(5)=occ_pers_diff;         % Rho_tau
moments(6)=wage_disc;               % Premium phi
moments(7)=wage_variance;           % Premium Tau
moments(8)=occ_change_rate;         % Baseline phi
moments(9)=avg_wage_disc_after_U;
moments(10)=slopeJF_after_unemp;
moments(11)=jobs_net;               % Premium n
moments(12)=unemp_benef;            % Unemployment benefits

mom=moments;

if nargin < 1
    save base_cal/moments.mat moments
else
    paramstring=sprintf('%g\\moments.mat',inputfolder); save(paramstring,'moments');
end
    
 
fprintf('Done! Time elapsed %g \n',toc(starttic));
end
