function res  = model_sons( inputfolder , theta_partial, fix_generations, u_state_fix_gen, e_state_fix_gen)
%FIRST PART: LOAD EVERYTHING THAT DOES NOT DEPEND ON FATHERS
maxNumCompThreads(8);

if nargin < 1
    %Parameters loaded here
    load base_cal/parameters_model.mat 
    load(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc));
else
    paramstring=sprintf('%g\\parameters_model.mat',inputfolder); load(paramstring);
    load(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc));
end

if nargin < 2, theta_partial=-100; end %default: General Equilibrium
if nargin < 3, fix_generations=false; end %default: let generations go to Steady State

starttic=tic;            

ncells_todivide=zeros(5,1);
ncells2_tozero=zeros(1,5);
ncells2_toones=zeros(1,5);
denom=zeros(1,5);
for kk=1:n_pos
    ncells2_tozero(kk)=sum((matrix_indexes_son(:,1)==kk).*(matrix_indexes_son(:,2)==0));
    ncells2_toones(kk)=sum((matrix_indexes_son(:,1)==kk).*(matrix_indexes_son(:,2)==1));
    denom(kk)=(ncells2_tozero(kk)+ncells2_toones(kk));
    ncells_todivide(kk)=sum(matrix_indexes_son(:,1)==kk);
end
adj1_son=(matrix_indexes_son(:,1)==1)'./ncells_todivide(1) + (n_occ-1)*(matrix_indexes_son(:,1)==2)'./ncells_todivide(2) + ...
    ((n_occ-1)*(matrix_indexes_son(:,1)==3))'./ncells_todivide(3) + ...
    ((n_occ-1)*(matrix_indexes_son(:,1)==4))'./ncells_todivide(4) + (n_occ-1)*(n_occ-2)*(matrix_indexes_son(:,1)==5)'./ncells_todivide(5);

%Adjust for persistence
adj1_son=adj1_son.*((matrix_indexes_son(:,2)==1)'.*denom(matrix_indexes_son(:,1)')./(ncells2_toones(matrix_indexes_son(:,1)')) + ...
    ((matrix_indexes_son(:,2)==0)'.*((n_occ-1).*denom(matrix_indexes_son(:,1)')./(ncells2_tozero(matrix_indexes_son(:,1)')))));%.*(1-factoradj(matrix_indexes_son(:,1)'))));

% Initialize Value Functions
w_son=piecerate.*productivity_son;
w_son=min(w_son,productivity_son);
w_son=max(w_son,0);

U_son=ones(statesize_son,1);   
W_son=ones(statesize_son,1);   
J_son=ones(statesize_son,1); 

Eu_U_son=U_son; Ee_U_son=U_son;
Eu_W_son=W_son; Ee_W_son=W_son;
E_J_son=J_son;

Eu_WR_son=Eu_U_son;
Ee_WR_son=Ee_W_son;

all_Ee_son=Ee_W_son;

firstguess_theta=0;   %This tells the program that theta has never been guessed

statesize_bef_fat=statesize_son/(statesize_fat*2);

u_state_old=(ones(1,statesize_son).*adj1_son./sum(adj1_son)).*0.1;
e_state_old=(ones(1,statesize_son).*adj1_son./sum(adj1_son))-u_state_old;

megaadj1_u=u_state_old;
megaadj1_e=e_state_old;

%ORDER OF VARIABLES
% 1) POSITION of son (1-5)
% 2) FOLLOWER (dummy)
% 3) STATE of father (1-20): position of father + HC of fat + NET of fat
% 4) ADV. of son == ADV. of fat (dummy)
% 5) PREF. of son == PREF. of fat (dummy)
% 6) ADV. of son == PREF. of fat (dummy)
% 7) PREF. of son == ADV. of fat (dummy)
% 8) OCC. of fat == ADV. of son (dummy)
% 9) OCC. of fat == PREF. of son (dummy)
% 10) OCC. of son == ADV. of fat (dummy)
% 11) OCC. of son == PREF. of fat (dummy)
% 12) E.S. of fat (1-2)
% 13) HC of son (1-2)
% 14) NET of son (1-2)

%WHERETOLOOK already built!

%PART 2: FINDING A SOLUTION TO THE JOINT PROBLEM
%% Value Function Iteration
VF=tic;
WR_son=ones(n_occ,statesize_son);
expectation_U_son=0*U_son;
old_WR_son=0*WR_son;
old_W_son=0*W_son;
old_U_son=0*U_son;
old_J_son=0*J_son;

iter_theta=0;
old_dist_zeroprofit=10;
dist_zeroprofit=10;

if theta_partial > 0
    theta=theta_partial;
else
    theta=min_theta+toll; %just one theta, this is random search with homogeneous occupations
end

initial_u_fathers=u_state_old';
initial_e_fathers=e_state_old';

while dist_zeroprofit > toll_tightness

    if nargin < 1
        if not(fix_generations) %special code for shutting down general equilibrium convergence of generations
            model_fathers(initial_u_fathers,initial_e_fathers,theta);
        end
        [trans_newson_U,trans_newson_E]=trans_newson_gen();
    else
        if not(fix_generations)
            model_fathers(initial_u_fathers,initial_e_fathers,theta,inputfolder);
        end
        [trans_newson_U,trans_newson_E]=trans_newson_gen(inputfolder);
    end
    
    if nargin < 1
    %Parameters loaded here
        load base_cal/parameters_model.mat 
        % Load fathers' problem:
        load base_cal/fathers.mat
    else
        paramstring=sprintf('%g\\parameters_model.mat',inputfolder); load(paramstring);
        fatherstring=sprintf('%g\\fathers.mat',inputfolder); load(fatherstring);
    end



%% Transition Function:


%ALGORITHM THAT REPLICATES ITEMS for fathers' occupational changes
transition_tic=tic;
small_state_son=matrix_indexes_son(1:statesize_son/(n_hc*n_net*n_es),1:11);
length=size(small_state_son,1);
%1) must check unique cases of transitions to 4 and to 5. transitions to 1,
%2 and 3 are always unique.
uniquecase=zeros(length,length);
occfathernow=matrix_indexes_father(matrix_indexes_son(1:length,3),1);
for jj=1:length
    sonstaysput=(matrix_indexes_son(jj,1)==matrix_indexes_son(1:length,1)).* ...
            (matrix_indexes_son(jj,4)==matrix_indexes_son(1:length,4)).* ...
            (matrix_indexes_son(jj,5)==matrix_indexes_son(1:length,5)).* ...
            (matrix_indexes_son(jj,6)==matrix_indexes_son(1:length,6)).* ...
            (matrix_indexes_son(jj,7)==matrix_indexes_son(1:length,7)).* ...
            (matrix_indexes_son(jj,10)==matrix_indexes_son(1:length,10)).* ...
            (matrix_indexes_son(jj,11)==matrix_indexes_son(1:length,11));
    for kk=1:length
        %new version
        transexists=(matrix_indexes_father(matrix_indexes_son(jj,3),1)==1)*(matrix_indexes_son(kk,3)==1 || matrix_indexes_son(kk,3)==4 || matrix_indexes_son(kk,3)==matrix_indexes_son(jj,3))+...
                        (matrix_indexes_father(matrix_indexes_son(jj,3),1)==2)*(matrix_indexes_son(kk,3)==2 || matrix_indexes_son(kk,3)==3 || matrix_indexes_son(kk,3)==5 || matrix_indexes_son(kk,3)==matrix_indexes_son(jj,3))+...
                        (matrix_indexes_father(matrix_indexes_son(jj,3),1)==3)*(matrix_indexes_son(kk,3)==2 || matrix_indexes_son(kk,3)==3 || matrix_indexes_son(kk,3)==5 || matrix_indexes_son(kk,3)==matrix_indexes_son(jj,3))+...
                        (matrix_indexes_father(matrix_indexes_son(jj,3),1)==4)*(matrix_indexes_son(kk,3)==1 || matrix_indexes_son(kk,3)==4 || matrix_indexes_son(kk,3)==matrix_indexes_son(jj,3))+...
                        (matrix_indexes_father(matrix_indexes_son(jj,3),1)==5)*(matrix_indexes_son(kk,3)==2 || matrix_indexes_son(kk,3)==3 || matrix_indexes_son(kk,3)==5 || matrix_indexes_son(kk,3)==matrix_indexes_son(jj,3));
        
        fatherisambiguous=(matrix_indexes_son(kk,3)>3).*(matrix_indexes_son(kk,3)<6);
        uniquecase(jj,kk)=sonstaysput(kk).*transexists.*fatherisambiguous;   
        %now, is this case uniquely identified by state?
        uniquecase(jj,kk)=uniquecase(jj,kk) .* ...
           (matrix_indexes_son(kk,2)*(1-matrix_indexes_son(jj,2))+matrix_indexes_son(kk,8)*(1-matrix_indexes_son(jj,8))+matrix_indexes_son(kk,9)*(1-matrix_indexes_son(jj,9))>0); 
       %at least one between x2, x8 and x9 must be > 1
       %that's it, unique cases within changes to 4 and 5 identified
    end
end

    howmanyunique=sum(uniquecase,2);    %vectorized
    %3) now where are you coming from? because if it's 1, there are n_occ-1
    %potential arrival points. if it's 2 or 3 or 4, there are n_occ-2. If it's 5,
    %there are n_occ-3.
    n_potential_occ=(n_occ-1)*(occfathernow==1) + ...
        (n_occ-2)*(occfathernow==2) + ...
        (n_occ-2)*(occfathernow==3) + ...
        (n_occ-2)*(occfathernow==4) + ...
        (n_occ-3)*(occfathernow==5);
    n_ambiguous_occ=n_potential_occ+( (matrix_indexes_son(1:length,3)==4)+(matrix_indexes_son(1:length,3)==5)>=1 );  %vectorized
    %n_replicate now contains the number of NON UNIQUELY IDENTIFIED
    %occupations for changes to 4 and 5
    n_replicate=n_potential_occ-howmanyunique;
    %actually it's not even necessary to replicate the item - just
    %multiply residual probability of transition to occupation 4 or 5 by
    %this number
    %use uniquecase(jj,kk) to identify whether that number needs
    %multiplying or not
%end

%ALGORITHM= 1 SECOND FOR THE ENTIRE TRANSITION
    small_state_son=matrix_indexes_son(1:statesize_son/(n_hc*n_net*n_es),1:11);
    
    length=size(small_state_son,1);
    
    %trans_son_small=eye(length,length);
    trans_prob_father_E=zeros(length,length);
    trans_prob_father_U=zeros(length,length);
    
    firstcheck=[matrix_indexes_son(1:length,1:2) matrix_indexes_son(1:length,4:end)];
    %Phase 1: transit state of father
    %NEW ALGORITHM: time 0.1 seconds
    for jj=1:length
        %Apply transition of father to all elements in row jj
        trans_prob_father_E(jj,:)=trans_father_E(matrix_indexes_son(jj,3),matrix_indexes_son(1:length,3));
        trans_prob_father_U(jj,:)=trans_father_U(matrix_indexes_son(jj,3),matrix_indexes_son(1:length,3));
        
        maxdiff2=((max(abs(firstcheck(jj,:)-firstcheck),[],2))>0);
        trans_prob_father_E(jj,(maxdiff2))=0;   %zero elements in which state of son changes
        trans_prob_father_U(jj,(maxdiff2))=0;

    end
    trans_son_small_father_E=trans_prob_father_E;
    trans_son_small_father_U=trans_prob_father_U;
    
    
    %New algorithm featuring several optimizations, time 0.72 sec
    %Phase 2: transit occupation of father
    trans_occ_father=zeros(length,length);   
    for jj=1:length

        check_withinfather=(matrix_indexes_father(matrix_indexes_son(jj,3),1)==matrix_indexes_father(matrix_indexes_son(1:length,3),1));
        idx_fat_jj=matrix_indexes_son(jj,3);
              
        for kk=1:length
            idx_fat_kk=matrix_indexes_son(kk,3);
             if (check_withinfather(kk)==0) || ...        
                (matrix_indexes_son(jj,2)~=(matrix_indexes_son(kk,2))) || ...
                (matrix_indexes_son(jj,8)~=(matrix_indexes_son(kk,8))) || ...     
                (matrix_indexes_son(jj,9)~=(matrix_indexes_son(kk,9))) || ...
                (idx_fat_jj>5 && idx_fat_kk<=5)
                
                                 occ_change_fat=1;    % Occupational change of father for sure!
            
             elseif (check_withinfather(kk)==1) || ...
                (matrix_indexes_son(jj,2)==(matrix_indexes_son(kk,2))) && ...
                (matrix_indexes_son(jj,8)==(matrix_indexes_son(kk,8))) && ...     
                (matrix_indexes_son(jj,9)==(matrix_indexes_son(kk,9))) && ...
                (idx_fat_jj>5 && idx_fat_kk<=5)==0
            
                     if matrix_indexes_father(idx_fat_jj,1)<4  || ...
                         ((matrix_indexes_son(jj,2)+matrix_indexes_son(jj,8)+matrix_indexes_son(jj,9))>0) || ...
                         idx_fat_kk>5 
                                 occ_change_fat=0;   % NOT Occupational change of father for sure!
                      else
                                 occ_change_fat=2;   % POSSIBLE Occupational change of father! 
                      end
             end
            
 
             if occ_change_fat==1
                 if idx_fat_kk<4
                       trans_occ_father(jj,kk)=trans_occ_fat(idx_fat_jj, idx_fat_kk);
                       
                 else
                      if matrix_indexes_son(jj,2)+matrix_indexes_son(kk,2)==2 || ...
                         matrix_indexes_son(jj,8)+matrix_indexes_son(kk,8)==2 || ...
                         matrix_indexes_son(jj,9)+matrix_indexes_son(kk,9)==2 || ...
                         idx_fat_kk>5
                            trans_occ_father(jj,kk)=0;  
                      else
                             if uniquecase(jj,kk)==1
                            trans_occ_father(jj,kk)=trans_occ_fat(idx_fat_jj, idx_fat_kk)*1/n_ambiguous_occ(jj);
                            
                             else
                            trans_occ_father(jj,kk)=trans_occ_fat(idx_fat_jj, idx_fat_kk)*n_replicate(jj)/n_ambiguous_occ(jj);     
                             end
                      end
                 end
             elseif occ_change_fat==0
                 if matrix_indexes_father(idx_fat_jj,1)<4    
                trans_occ_father(jj,kk)=trans_occ_fat(idx_fat_jj, idx_fat_kk); 
                
                 elseif jj==kk
                        trans_occ_father(jj,kk)=prob_choosing_occ_fat(idx_fat_jj,1);
                        
                     else
                         trans_occ_father(jj,kk)=trans_occ_fat(idx_fat_jj, idx_fat_kk)/n_potential_occ(jj);     
                         
                 end
             elseif occ_change_fat==2
                trans_occ_father(jj,kk)=trans_occ_fat(idx_fat_jj, idx_fat_kk)*(n_replicate(jj)+1)/n_ambiguous_occ(jj); 
                
             end 
             
             if matrix_indexes_son(jj,1)==matrix_indexes_son(kk,1) && ...
               matrix_indexes_son(jj,4)==matrix_indexes_son(kk,4) && ...
               matrix_indexes_son(jj,5)==matrix_indexes_son(kk,5) && ...
               matrix_indexes_son(jj,6)==matrix_indexes_son(kk,6) && ...
               matrix_indexes_son(jj,7)==matrix_indexes_son(kk,7) && ...
               matrix_indexes_son(jj,10)==matrix_indexes_son(kk,10) && ...
               matrix_indexes_son(jj,11)==matrix_indexes_son(kk,11)
              % Do nothing
             else
                trans_occ_father(jj,kk)=0;
             end 
        end
    end
    %We must take into account that
    %trans_occ applies only to fathers who either 1) become unemployed 2)
    %are already unemployed and DO NOT find a job   
    %each matrix must be multiplied by the appropriate JF and JS of the
    %father
    jobfind_fat_forsons=(jobfind_fat.*(1-(trans_father_U*probleave_emp_fat)));  
    jobsep_fat=delta + (1-delta).*(trans_father_E*probleave_emp_fat);
    
    jfind_t_f=zeros(length,length);
    jsep_t_f=zeros(length,length);
    for jj=1:length
        jfind_t_f(jj,:)=jobfind_fat_forsons(matrix_indexes_son(jj,3));
        jsep_t_f(jj,:)=jobsep_fat(matrix_indexes_son(jj,3));
    end
    
    trans_son_father_E=(1-jsep_t_f).*trans_son_small_father_E;
    trans_son_father_U=jfind_t_f.*trans_son_small_father_U;
    trans_son_father_E_wocc=(jsep_t_f.*trans_son_small_father_E)*trans_occ_father;
    trans_son_father_U_wocc=((1-jfind_t_f).*trans_son_small_father_U)*trans_occ_father;   
    
    %now stack matrices together! they must be multiplied by the
    %appropriate JF probability and JS probability of the father though
    
    omega1_trans_son=[trans_son_father_U_wocc trans_son_father_U; 
        trans_son_father_E_wocc trans_son_father_E];
    
    %now apply HC and NET transition
    total_trans_omega_E=sparse(kron(net_trans_E,kron(hc_trans_E,omega1_trans_son)));
    total_trans_omega_U=sparse(kron(net_trans_U,kron(hc_trans_U,omega1_trans_son)));
    
    total_trans_omega_E=total_trans_omega_E./sum(total_trans_omega_E,2);
    total_trans_omega_U=total_trans_omega_U./sum(total_trans_omega_U,2);
    
    %FINISHED!!!!!! these are now the transition matrices of the state for sons!!!

%all these must be computed only ONCE (they do not depend on the son's
%problem
Eu_W_father=total_trans_omega_U*W_father(whichfather);
Ee_W_father=total_trans_omega_E*W_father(whichfather);
Eu_WR_father_rep=total_trans_omega_U*WR_father_rep(whichfather);
Ee_WR_father_rep=total_trans_omega_E*WR_father_rep(whichfather);
E_J_father=total_trans_omega_E*J_father(whichfather);


%Starting from a less meaningless THETA
flowvalue_firm=productivity_son - w_son + disc.*(((1-delta).*(zeta_par.*E_J_father)));
if firstguess_theta == 0
    
    distJ=100;
    while distJ > toll
        J_son=(((flowvalue_firm + disc.*((((1-delta).*((1-zeta_par).*(total_trans_omega_E*J_son))))))));
        distJ=max(abs(J_son-old_J_son));
        old_J_son=J_son;
    end
    theta_old=1;
    theta=0.5;
    while abs(theta-theta_old) > toll
        
        theta_old=theta;
        jobfind_son=min(jf_function(theta).*(net_son./sum(((u_state_old').*net_son)./sum(u_state_old))),0.99999);
               
        %Value function of firms: the expected value of hiring a son
        %(0.5 probability) or a father (0.5 probability)
        E_J_TOTAL=0.5*((sum(u_state_old.*jobfind_son'.*(J_son')))./sum(u_state_old.*jobfind_son')) + ...
            0.5*((sum(u_state_fat.*jobfind_fat'.*(J_father')))./sum(u_state_fat.*jobfind_fat'));

        E_J_TOTAL=round(E_J_TOTAL*(10^10))./(10^10);
        
        theta=(q_inverse(kappa./(E_J_TOTAL)));
        
    end
    firstguess_theta=1;
end

    w_son=piecerate.*productivity_son;
    w_son=min(w_son,productivity_son);
    w_son=max(w_son,0);
    jobfind_son=min(jf_function(theta).*(net_son./sum(((u_state_old').*net_son)./sum(u_state_old))),0.99999);
    
    %Solve worker and firm's problem
    
    iter=0;
    dist=100;
    distW=100;
    distU=100;
    
    %precalculation for W_son_provv
    precalc_W_son_provv=((pref_son + w_son + disc.*((1-delta).*(zeta_par.*Ee_W_father) + ...
        delta.*(zeta_par.*Ee_WR_father_rep))));
    
    precalc_U_son=(b + disc.*((jobfind_son.*(zeta_par.*Eu_W_father) + ...
        (1-jobfind_son).*(zeta_par.*Eu_WR_father_rep))));
    jf_son_disc_zeta=disc.*((jobfind_son.*((1-zeta_par))));
    nojf_son_disc_zeta=disc.*(((1-jobfind_son).*((1-zeta_par))));
    
    flowvalue_firm=productivity_son - w_son + disc.*(((1-delta).*(zeta_par.*E_J_father)));
        
    while max(distW,distU) > toll
        iter=iter+1;
        
        WR_son_REP_horizontally=U_son(wheretolook_son);

        scalingdown_factor=(max(WR_son_REP_horizontally,[],2));    %Line-by-line scaling for precision

        WR_son_REP_horizontally_scaleddown=WR_son_REP_horizontally-repmat(scalingdown_factor,1,n_occ);

        expWR_son_REP_hs=exp(WR_son_REP_horizontally_scaleddown/sigma_shocks);

        sums=sum(expWR_son_REP_hs,2);   %This code rescales the value functions for more precise EXP
        
        prob_choosing_occ=bsxfun(@ldivide,sums,expWR_son_REP_hs);
        
        
        %Bounding (im)mobility above
        prob_choosing_occ=min(prob_choosing_occ,upperbound_probabilities);
        prob_choosing_occ=max(prob_choosing_occ,lowerbound_probabilities);
        
        prob_choosing_occ=bsxfun(@ldivide,sum(prob_choosing_occ,2),prob_choosing_occ);
        
        WR_son_rep=sum(prob_choosing_occ.*(WR_son_REP_horizontally),2);

        U_son=precalc_U_son + jf_son_disc_zeta.*Eu_W_son + nojf_son_disc_zeta.*Eu_WR_son;
        
        %another optimization - expectation written in a more efficient way
        W_son_provv=all_Ee_son + precalc_W_son_provv;
        
        probleave_emp=((1-((1./(1 + exp((WR_son_rep-W_son_provv)./sigma_shocks))))).*(10^10))./(10^10); %speedup
       
       % BOUNDING PROBLEAVE
       probleave_emp=max(probleave_emp,1-upperbound_probabilities);
       probleave_emp=min(probleave_emp,upperbound_probabilities);
       
       W_son=(((1-probleave_emp).*W_son_provv) + probleave_emp.*WR_son_rep);

       %Computing Expectations
       Eu_W_son=total_trans_omega_U*W_son;  

       Eu_WR_son=total_trans_omega_U*WR_son_rep;
               
        all_Ee_son=total_trans_omega_E*(((disc.*(1-zeta_par).*(((1-delta).*W_son) + ...
            delta.*(WR_son_rep))))); 

        distW=max(abs(W_son-old_W_son));
        distU=max(abs(U_son-old_U_son));
        old_W_son=W_son;
        old_U_son=U_son;
    end
    
    %Separate code for convergence of J
    distJ=100;
    while distJ > toll
        J_son=(((1-probleave_emp).*(flowvalue_firm + disc.*((((1-delta).*((1-zeta_par).*(total_trans_omega_E*J_son))))))));
        distJ=max(abs(J_son-old_J_son));
        old_J_son=J_son;
    end
    E_J_son=total_trans_omega_E*J_son;
    
    % SPARSE VERSION:
    % indicator of rows:
    A=kron([1:statesize_son]',ones(n_occ,1));
    % indicator of columns:
    B=reshape(double(wheretolook_son'), statesize_son*n_occ,1);
    % values:
    C=reshape(prob_choosing_occ', statesize_son*n_occ,1);
    trans_occ_son=sparse(A,B,C,statesize_son,statesize_son);   
    
    probleave_emp_trans=probleave_emp';
    jf_trans=jobfind_son';
    
    %Solve for steady state distribution over states
    if iter_theta < 3
        u_state_sons=megaadj1_u;
        e_state_sons=megaadj1_e;
    else
        weight_comp_measure=0.1*(1/(iter-2));
        u_state_sons=(1-weight_comp_measure)*u_state_sons + weight_comp_measure*megaadj1_u;
        e_state_sons=(1-weight_comp_measure)*e_state_sons + weight_comp_measure*megaadj1_e;
    end
    
    u_state_old=u_state_sons*2;
    e_state_old=e_state_sons*2;
   
    zeta_par_trans_newson_U=sparse(zeta_par.*trans_newson_U);
    zeta_par_trans_newson_E=sparse(zeta_par.*trans_newson_E);
    
    probleave_emp_trans_zeta_par=probleave_emp_trans.*(1-zeta_par);
    oneminus_probleave_emp_trans_zeta_par=(1-probleave_emp_trans).*(1-zeta_par);
        
    iter_distrib=0;
    dist_distrib=1;
    
    %if generations are fixed, these must be computed only once
    if fix_generations
       newborns_all=u_state_fix_gen*zeta_par_trans_newson_U + e_state_fix_gen*zeta_par_trans_newson_E;
    end
       
    while (dist_distrib == 1)
        iter_distrib=iter_distrib+1;

        u_state_old=u_state_sons;
        e_state_old=e_state_sons;
               
        if not(fix_generations)
            newborns_all=u_state_sons*zeta_par_trans_newson_U + e_state_sons*zeta_par_trans_newson_E;
        end
                        
        measure1=(((((((1-zeta_par).*u_state_sons + (((newborns_all))))) + ...
             (((probleave_emp_trans_zeta_par).*e_state_sons))))*trans_occ_son))*total_trans_omega_U;
         
        measure2=((((oneminus_probleave_emp_trans_zeta_par).*e_state_sons)))*total_trans_omega_E;
        
        u_state_sons=(((1-jf_trans).*measure1)) + ...
            (delta.*measure2);
        e_state_sons=(((jf_trans).*measure1)) + ...
            ((1-delta).*measure2);
        
        if mod(iter_distrib,5) == 0   %Calculates distance infrequently, it's not really necessary to do it everytime
            dist_distrib=((max(abs(u_state_sons-u_state_old)) > toll) || (max(abs(e_state_sons-e_state_old)) > toll));
        end

    end
    
    E_J_TOTAL=0.5*((sum(u_state_sons.*jobfind_son'.*(J_son')))./sum(u_state_sons.*jobfind_son')) + ...
        0.5*((sum(u_state_fat.*jobfind_fat'.*(J_father')))./sum(u_state_fat.*jobfind_fat'));
    
    E_J_TOTAL=round(E_J_TOTAL*(10^10))./(10^10);
    iter_theta=iter_theta+1;
    
    zeroprofit=(q_fun(theta)-kappa./(E_J_TOTAL));
    old_dist_zeroprofit=dist_zeroprofit;
    dist_zeroprofit=max(abs(zeroprofit));
       
    speedofadj=0.99;
    if dist_zeroprofit < old_dist_zeroprofit
        adj_weight=max(adj_weight.*speedofadj,0.1);
    else
        adj_weight=min(adj_weight.*(1.1),0.99);
    end

    theta_aimed=(q_inverse(kappa./(E_J_TOTAL)));
    
    if theta_partial > 0
        theta=theta_partial;
        dist_zeroprofit=100;
        if iter_theta == 10, dist_zeroprofit=0; end
    else
        theta=adj_weight.*theta + (1-adj_weight).*theta_aimed; %new guess
        if dist_zeroprofit < old_dist_zeroprofit, besttheta=theta; end
        if iter > 2 && dist_zeroprofit >= old_dist_zeroprofit, theta=besttheta; end %keep theta closer to best

    end
    
    
    %NEW INPUTS FOR FATHERS! STEADY STATE DISTRIBUTION OF SONS
    initial_u_fathers=u_state_sons';
    initial_e_fathers=e_state_sons';

    fprintf('Iteration %g, New guess for theta is = %g, zero profit = %g \n',iter_theta,mean(theta),dist_zeroprofit);
end

fprintf('VF and SS measures computed, time elapsed %g seconds \n',toc(starttic));
res=0;

probleave_emp_son=probleave_emp;

if nargin < 1
    save base_cal/sons.mat trans_occ_son whichfather jobfind_son...
        jobfind_fat_forsons probleave_emp_son w_son U_son W_son J_son ...
        Ee_W_son Eu_W_son Ee_WR_son Eu_WR_son E_J_son u_state_sons e_state_sons theta  ...
        total_trans_omega_U total_trans_omega_E wheretolook_son prob_choosing_occ
else
    outstring=sprintf('%g\\sons.mat',inputfolder);
    save(outstring,'trans_occ_son','whichfather', 'jobfind_son', ...
        'jobfind_fat_forsons', 'probleave_emp_son', 'w_son', 'U_son',  'W_son', 'J_son', ...
        'Ee_W_son',  'Eu_W_son', 'Ee_WR_son', 'Eu_WR_son', 'E_J_son', 'u_state_sons', 'e_state_sons', 'theta', ...
        'total_trans_omega_U', 'total_trans_omega_E','wheretolook_son','prob_choosing_occ');
end
end