function [trans_newson_U,trans_newson_E] = trans_newson_gen( inputfolder)

if nargin < 1
    %Parameters loaded here
    load base_cal/parameters_model.mat 
    % Load fathers' problem:
    load base_cal/fathers.mat
else
    paramstring=sprintf('%g\\parameters_model.mat',inputfolder); load(paramstring);
    fatherstring=sprintf('%g\\fathers.mat',inputfolder); load(fatherstring);
end


% 1) Construct father's position-specific matrices, with all possible sons'
% types
        aux_trans_fat=ones(n_pos,n_occ^2);
        [j1_ind_son, j2_ind_son]=ind2sub([n_occ n_occ],1:n_occ*n_occ);
        matrix_indexes_type_son=[j1_ind_son' j2_ind_son'];
        fat_pos_type=[1 1;1 2;2 1;2 2;2 3];   
            for j=1:5   % 5 possible positions
                for k=1:n_occ^2
                            if matrix_indexes_type_son(k,1)==fat_pos_type(j,1)
                                aux_trans_fat(j,k)=aux_trans_fat(j,k)*pers_adv;
                            else
                                aux_trans_fat(j,k)=aux_trans_fat(j,k)*(1-pers_adv)/(n_occ-1);                        
                            end
                            if matrix_indexes_type_son(k,2)==fat_pos_type(j,2)
                                aux_trans_fat(j,k)=aux_trans_fat(j,k)*pers_pref;
                            else
                                aux_trans_fat(j,k)=aux_trans_fat(j,k)*(1-pers_pref)/(n_occ-1);                        
                            end
                end
            end

            % Now convert into son's position (1) and intergenerational correlations (8):
                 for fat_pos=1:5
                     type_son_into_pos_and_corr{fat_pos}=999*ones(n_occ^2,9);
                     adv_fat=fat_pos_type(fat_pos,1);
                     pref_fat=fat_pos_type(fat_pos,2);
                    for j=1:n_occ^2
                        % Assign position of son
                        if matrix_indexes_type_son(j,1)==1 && matrix_indexes_type_son(j,2)==1
                        type_son_into_pos_and_corr{fat_pos}(j,1)=1;
                        elseif matrix_indexes_type_son(j,1)==1 && matrix_indexes_type_son(j,2)~=1
                        type_son_into_pos_and_corr{fat_pos}(j,1)=2;
                        elseif matrix_indexes_type_son(j,1)~=1 && matrix_indexes_type_son(j,2)==1
                        type_son_into_pos_and_corr{fat_pos}(j,1)=3;
                        elseif matrix_indexes_type_son(j,1)~=1 && matrix_indexes_type_son(j,2)~=1
                            if matrix_indexes_type_son(j,1)==matrix_indexes_type_son(j,2)
                        type_son_into_pos_and_corr{fat_pos}(j,1)=4;
                            else
                        type_son_into_pos_and_corr{fat_pos}(j,1)=5;        
                            end
                        end
                        % Assign correlations
                        type_son_into_pos_and_corr{fat_pos}(j,2)=(matrix_indexes_type_son(j,1)==adv_fat);
                        type_son_into_pos_and_corr{fat_pos}(j,3)=(matrix_indexes_type_son(j,2)==pref_fat);
                        type_son_into_pos_and_corr{fat_pos}(j,4)=(matrix_indexes_type_son(j,1)==pref_fat);
                        type_son_into_pos_and_corr{fat_pos}(j,5)=(matrix_indexes_type_son(j,2)==adv_fat);               
                        type_son_into_pos_and_corr{fat_pos}(j,6)=(matrix_indexes_type_son(j,1)==1);  
                        type_son_into_pos_and_corr{fat_pos}(j,7)=(matrix_indexes_type_son(j,2)==1);  
                        type_son_into_pos_and_corr{fat_pos}(j,8)=(fat_pos_type(fat_pos,1)==1);
                        type_son_into_pos_and_corr{fat_pos}(j,9)=(fat_pos_type(fat_pos,2)==1);
                    end
                 end

            % Group terms that correspond to same inherent son type:
         for fat_pos=1:5
           unique_val=unique(type_son_into_pos_and_corr{fat_pos},'rows');
           num_val=size(unique_val,1);
           prob=999*ones(num_val,1);
           for jj=1:num_val
           prob(jj)=sum(aux_trans_fat(fat_pos,:)'.*(ismember(type_son_into_pos_and_corr{fat_pos}, unique_val(jj,:),'rows')));    
           end
           possible_states{fat_pos}=[unique_val prob];
         end
 
         
 % 2) Construct the trans_newson_gen matrix
     % Extract "small" matrix
   small_state_son=matrix_indexes_son(1:statesize_son/(n_hc*n_net*n_es),:);
   length_small=size(small_state_son,1);
    
   % Create one such "small" matrix for each combination of HC and NET 
   % NO HC, NO NET
   tic
   stackingIuse=[small_state_son(:,1) small_state_son(:,4) small_state_son(:,5) ...
                   small_state_son(:,6) small_state_son(:,7) small_state_son(:,8) ...
                   small_state_son(:,9) small_state_son(:,10) small_state_son(:,11)];
   allpreviousconditions=(small_state_son(:,2)==1) & ...
                   small_state_son(:,13)==1 & ...
                   small_state_son(:,14)==1;
               
   %stack all information that is important into a huge matrix
   for fat_type=1:5
       num_poss_sons=size(possible_states{fat_type},1);
       possible_states_nocell=possible_states{fat_type};
       for ii=1:num_poss_sons
          correspondence_rows{fat_type}(:,ii)=ismember(stackingIuse,possible_states_nocell(ii,1:9),'rows');
       end
   end
       for kk=1:n_hc*n_net    %4               % We need to cycle across values of HC and NET (for father tomorrow!)
           
           trans_newson_gen_small{kk}=zeros(length_small,length_small);
           
               for jj=1:length_small
                  % jj
                   fat_type=matrix_indexes_son(jj,1);
                   % Cycle across possible son types and assign probability
                   num_poss_sons=size(possible_states{fat_type},1);
                   possible_states_nocell=possible_states{fat_type};
                  allconditions2=allpreviousconditions & (small_state_son(:,3)==whichfather(jj+(length_small*(2*(kk-1))))); 

                   for ii=1:num_poss_sons
                       trans_newson_gen_small{kk}(jj,(correspondence_rows{fat_type}(:,ii) & allconditions2))=possible_states_nocell(ii,10);
                   end
               end
       end
   
   trans_newson_U=sparse(statesize_son,statesize_son);
   trans_newson_E=sparse(statesize_son,statesize_son);
   for kk=1:n_hc*n_net
       trans_newson_U((kk-1)*2*length_small+1 : kk*2*length_small,1:length_small)=repmat(trans_newson_gen_small{kk},2,1);
       trans_newson_E((kk-1)*2*length_small+1 : kk*2*length_small,length_small+1:length_small*2)=repmat(trans_newson_gen_small{kk},2,1);
   end
   

